<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Task\IdleLoop;

// Import Framework stuff
use Org\Mxchange\CoreFramework\Task\BaseTask;
use Org\Mxchange\CoreFramework\Task\Taskable;
use Org\Mxchange\CoreFramework\Visitor\Visitable;
use Org\Mxchange\CoreFramework\Visitor\Visitor;

/**
 * A IdleLoop task
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class IdleLoopTask extends BaseTask implements Taskable, Visitable {
	/**
	 * Idle loop time
	 */
	private $idleTime = 0;

	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Init idle loop time from config ("cache" it here)
		$this->idleTime = $this->getConfigInstance()->getConfigEntry('idle_loop_time');
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$taskInstance	An instance of a Taskable/Visitable class
	 */
	public static final function createIdleLoopTask () {
		// Get new instance
		$taskInstance = new IdleLoopTask();

		// Return the prepared instance
		return $taskInstance;
	}

	/**
	 * Accepts the visitor to process the visitor
	 *
	 * @param	$visitorInstance	An instance of a Visitor class
	 * @return	void
	 */
	public function accept (Visitor $visitorInstance) {
		// Visit this task
		$visitorInstance->visitTask($this);
	}

	/**
	 * Executes the task
	 *
	 * @return	void
	 */
	public function executeTask () {
		// Idle here a little
		$this->idle($this->idleTime);
	}

	/**
	 * Shutdown this task, this does nothing here, just supply the method.
	 *
	 * @return	void
	 */
	public function doShutdown () {
		// Debug message
		self::createDebugInstance(__CLASS__, __LINE__)->debugOutput('TASK[' . __METHOD__ . ':' . __LINE__ . ']: Shutting down...');
	}

}
